@@ -59,11 +59,6 @@
 /* Cool-off period between last file modification time and thumbnail creation */
 #define THUMBNAIL_CREATION_DELAY_SECS 3
 
-#define NAUTILUS_THUMBNAIL_FRAME_LEFT 3
-#define NAUTILUS_THUMBNAIL_FRAME_TOP 3
-#define NAUTILUS_THUMBNAIL_FRAME_RIGHT 3
-#define NAUTILUS_THUMBNAIL_FRAME_BOTTOM 3
-
 static gpointer thumbnail_thread_start (gpointer data);
 
 /* structure used for making thumbnails, associating a uri with where the thumbnail is to be stored */
@@ -190,51 +185,6 @@ thumbnail_thread_starter_cb (gpointer data)
 	return FALSE;
 }
 
-static GdkPixbuf *
-nautilus_get_thumbnail_frame (void)
-{
-	static GdkPixbuf *thumbnail_frame = NULL;
-
-	if (thumbnail_frame == NULL) {
-		GInputStream *stream = g_resources_open_stream ("/org/gnome/nautilus/icons/thumbnail_frame.png", 0, NULL);
-		if (stream != NULL) {
-			thumbnail_frame = gdk_pixbuf_new_from_stream (stream, NULL, NULL);
-			g_object_unref (stream);
-		}
-	}
-	
-	return thumbnail_frame;
-}
-
-
-void
-nautilus_thumbnail_frame_image (GdkPixbuf **pixbuf)
-{
-	GdkPixbuf *pixbuf_with_frame, *frame;
-	int left_offset, top_offset, right_offset, bottom_offset;
-		
-	/* The pixbuf isn't already framed (i.e., it was not made by
-	 * an old Nautilus), so we must embed it in a frame.
-	 */
-
-	frame = nautilus_get_thumbnail_frame ();
-	if (frame == NULL) {
-		return;
-	}
-	
-	left_offset = NAUTILUS_THUMBNAIL_FRAME_LEFT;
-	top_offset = NAUTILUS_THUMBNAIL_FRAME_TOP;
-	right_offset = NAUTILUS_THUMBNAIL_FRAME_RIGHT;
-	bottom_offset = NAUTILUS_THUMBNAIL_FRAME_BOTTOM;
-	
-	pixbuf_with_frame = eel_embed_image_in_frame
-		(*pixbuf, frame,
-		 left_offset, top_offset, right_offset, bottom_offset);
-	g_object_unref (*pixbuf);	
-
-	*pixbuf = pixbuf_with_frame;
-}
-
 void
 nautilus_thumbnail_remove_from_queue (const char *file_uri)
 {
@@ -317,8 +267,6 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 {
 	NautilusFile *file;
 
-	gdk_threads_enter ();
-
 	file = nautilus_file_get_by_uri ((char *) image_uri);
 #ifdef DEBUG_THUMBNAILS
 	g_message ("(Thumbnail Thread) Notifying file changed file:%p uri: %s\n", file, (char*) image_uri);
@@ -333,8 +281,6 @@ thumbnail_thread_notify_file_changed (gpointer image_uri)
 	}
 	g_free (image_uri);
 
-	gdk_threads_leave ();
-
 	return FALSE;
 }
 
