@@ -399,25 +399,10 @@ realized_callback (GtkWidget *widget, NautilusDesktopCanvasView *desktop_canvas_
 {
 	GdkWindow *root_window;
 	GdkScreen *screen;
-	GtkAllocation allocation;
 
 	g_return_if_fail (desktop_canvas_view->details->root_window == NULL);
 
 	screen = gtk_widget_get_screen (widget);
-
-	/* Ugly HACK for the problem that the views realize at the
-	 * wrong size and then get resized. (This is a problem with
-	 * BonoboPlug.) This was leading to problems where initial
-	 * layout was done at 60x60 stacking all desktop icons in
-	 * the top left corner.
-	 */
-	allocation.x = 0;
-	allocation.y = 0;
-	allocation.width = gdk_screen_get_width (screen);
-	allocation.height = gdk_screen_get_height (screen);
-	gtk_widget_size_allocate (GTK_WIDGET(get_canvas_container(desktop_canvas_view)),
-				  &allocation);
-	
 	root_window = gdk_screen_get_root_window (screen);
 
 	desktop_canvas_view->details->root_window = root_window;
@@ -597,12 +582,6 @@ nautilus_desktop_canvas_view_init (NautilusDesktopCanvasView *desktop_canvas_vie
 	nautilus_view_set_show_foreign (NAUTILUS_VIEW (desktop_canvas_view),
 					FALSE);
 	
-	/* Set our default layout mode */
-	nautilus_canvas_container_set_layout_mode (canvas_container,
-						 gtk_widget_get_direction (GTK_WIDGET(canvas_container)) == GTK_TEXT_DIR_RTL ?
-						 NAUTILUS_CANVAS_LAYOUT_T_B_R_L :
-						 NAUTILUS_CANVAS_LAYOUT_T_B_L_R);
-
 	g_signal_connect_object (canvas_container, "middle_click",
 				 G_CALLBACK (nautilus_desktop_canvas_view_handle_middle_click), desktop_canvas_view, 0);
 	g_signal_connect_object (desktop_canvas_view, "realize",
