@@ -217,7 +217,7 @@ application_launch_parameters_new (GAppInfo *application,
 
 	result = g_new0 (ApplicationLaunchParameters, 1);
 	result->application = g_object_ref (application);
-	result->uris = eel_g_str_list_copy (uris);
+	result->uris = g_list_copy_deep (uris, (GCopyFunc) g_strdup, NULL);
 
 	return result;
 }
@@ -2069,6 +2069,13 @@ activation_get_activation_uris (ActivateParameters *parameters)
 			parameters->locations = g_list_delete_link (parameters->locations, l);
 			continue;
 		}
+		
+		if (nautilus_file_is_symbolic_link (file)) {
+			nautilus_file_invalidate_attributes 
+				(file,
+				 NAUTILUS_FILE_ATTRIBUTE_INFO |
+				 NAUTILUS_FILE_ATTRIBUTE_LINK_INFO);
+		}
 	}
 
 	if (parameters->locations == NULL) {
