@@ -129,7 +129,6 @@ enum {
 	PLACES_SIDEBAR_COLUMN_NO_EJECT,
 	PLACES_SIDEBAR_COLUMN_BOOKMARK,
 	PLACES_SIDEBAR_COLUMN_TOOLTIP,
-	PLACES_SIDEBAR_COLUMN_EJECT_GICON,
 	PLACES_SIDEBAR_COLUMN_SECTION_TYPE,
 	PLACES_SIDEBAR_COLUMN_HEADING_TEXT,
 
@@ -205,37 +204,6 @@ static GtkListStore *nautilus_shortcuts_model_new (NautilusPlacesSidebar *sideba
 
 G_DEFINE_TYPE (NautilusPlacesSidebar, nautilus_places_sidebar, GTK_TYPE_SCROLLED_WINDOW);
 
-static gboolean
-is_built_in_bookmark (NautilusFile *file)
-{
-	gboolean built_in;
-	gint idx;
-
-	if (nautilus_file_is_home (file)) {
-		return TRUE;
-	}
-
-	if (nautilus_file_is_desktop_directory (file) &&
-	    !g_settings_get_boolean (gnome_background_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
-		return FALSE;
-	}
-
-	built_in = FALSE;
-
-	for (idx = 0; idx < G_USER_N_DIRECTORIES; idx++) {
-		/* PUBLIC_SHARE and TEMPLATES are not in our built-in list */
-		if (nautilus_file_is_user_special_directory (file, idx)) {
-			if (idx != G_USER_DIRECTORY_PUBLIC_SHARE &&  idx != G_USER_DIRECTORY_TEMPLATES) {
-				built_in = TRUE;
-			}
-
-			break;
-		}
-	}
-
-	return built_in;
-}
-
 static GtkTreeIter
 add_heading (NautilusPlacesSidebar *sidebar,
 	     SectionType section_type,
@@ -295,7 +263,6 @@ add_place (NautilusPlacesSidebar *sidebar,
 	   const char *tooltip)
 {
 	GtkTreeIter           iter;
-	GIcon *eject;
 	gboolean show_eject, show_unmount;
 	gboolean show_eject_button;
 
@@ -314,12 +281,6 @@ add_place (NautilusPlacesSidebar *sidebar,
 		show_eject_button = (show_unmount || show_eject);
 	}
 
-	if (show_eject_button) {
-		eject = g_themed_icon_new_with_default_fallbacks ("media-eject-symbolic");
-	} else {
-		eject = NULL;
-	}
-
 	gtk_list_store_append (sidebar->store, &iter);
 	gtk_list_store_set (sidebar->store, &iter,
 			    PLACES_SIDEBAR_COLUMN_GICON, icon,
@@ -334,13 +295,8 @@ add_place (NautilusPlacesSidebar *sidebar,
 			    PLACES_SIDEBAR_COLUMN_NO_EJECT, !show_eject_button,
 			    PLACES_SIDEBAR_COLUMN_BOOKMARK, place_type != PLACES_BOOKMARK,
 			    PLACES_SIDEBAR_COLUMN_TOOLTIP, tooltip,
-			    PLACES_SIDEBAR_COLUMN_EJECT_GICON, eject,
 			    PLACES_SIDEBAR_COLUMN_SECTION_TYPE, section_type,
 			    -1);
-
-	if (eject != NULL) {
-		g_object_unref (eject);
-	}
 }
 
 typedef struct {
@@ -423,12 +379,12 @@ add_special_dirs (NautilusPlacesSidebar *sidebar)
 
 	dirs = NULL;
 	for (index = 0; index < G_USER_N_DIRECTORIES; index++) {
-		const char *path;
+		const char *path, *name;
 		GFile *root;
 		GIcon *icon;
-		char *name;
 		char *mount_uri;
-		char *tooltip;
+		NautilusBookmark *bookmark;
+		guint idx;
 
 		if (index == G_USER_DIRECTORY_DESKTOP ||
 		    index == G_USER_DIRECTORY_TEMPLATES ||
@@ -449,21 +405,36 @@ add_special_dirs (NautilusPlacesSidebar *sidebar)
 		}
 
 		root = g_file_new_for_path (path);
-		name = g_file_get_basename (root);
-		icon = nautilus_special_directory_get_symbolic_icon (index);
+
+		/* Don't add the bookmark to the sidebar if it was removed from
+		 * the user dir list, or if its location doesn't exist.
+		 */
+		bookmark = nautilus_bookmark_list_item_with_location (sidebar->bookmarks, root, &idx);
+		if (bookmark && !nautilus_bookmark_get_exists (bookmark)) {
+			g_object_unref (root);
+			continue;
+		}
+
+		if (bookmark) {
+			name = g_strdup (nautilus_bookmark_get_name (bookmark));
+			icon = nautilus_bookmark_get_symbolic_icon (bookmark);
+		} else {
+			name = g_file_get_basename (root);
+			icon = nautilus_special_directory_get_symbolic_icon (index);
+			idx = -1;
+		}
+
 		mount_uri = g_file_get_uri (root);
-		tooltip = g_file_get_parse_name (root);
 
 		add_place (sidebar, PLACES_XDG_DIR,
 			   SECTION_COMPUTER,
 			   name, icon, mount_uri,
-			   NULL, NULL, NULL, 0,
-			   tooltip);
-		g_free (name);
+			   NULL, NULL, NULL, idx,
+			   name);
+
 		g_object_unref (root);
 		g_object_unref (icon);
 		g_free (mount_uri);
-		g_free (tooltip);
 
 		dirs = g_list_prepend (dirs, (char *)path);
 	}
@@ -493,7 +464,6 @@ update_places (NautilusPlacesSidebar *sidebar)
 	NautilusWindowSlot *slot;
 	char *tooltip;
 	GList *network_mounts, *network_volumes;
-	NautilusFile *file;
 
 	DEBUG ("Updating places sidebar");
 
@@ -766,20 +736,17 @@ update_places (NautilusPlacesSidebar *sidebar)
 
 	for (index = 0; index < bookmark_count; ++index) {
 		bookmark = nautilus_bookmark_list_item_at (sidebar->bookmarks, index);
-
-		if (nautilus_bookmark_uri_known_not_to_exist (bookmark)) {
-			continue;
-		}
-
 		root = nautilus_bookmark_get_location (bookmark);
-		file = nautilus_file_get (root);
 
-		if (is_built_in_bookmark (file)) {
+		if (!nautilus_bookmark_get_exists (bookmark) && g_file_is_native (root)) {
+			g_object_unref (root);
+			continue;
+		}
+
+		if (nautilus_bookmark_get_is_builtin (bookmark)) {
 			g_object_unref (root);
-			nautilus_file_unref (file);
 			continue;
 		}
-		nautilus_file_unref (file);
 
 		bookmark_name = nautilus_bookmark_get_name (bookmark);
 		icon = nautilus_bookmark_get_symbolic_icon (bookmark);
@@ -1025,52 +992,41 @@ desktop_setting_changed_callback (gpointer user_data)
 }
 
 static void
-update_current_uri (NautilusPlacesSidebar *sidebar)
+loading_uri_callback (NautilusWindow *window,
+		      char *location,
+		      NautilusPlacesSidebar *sidebar)
 {
 	GtkTreeSelection *selection;
 	GtkTreeIter 	 iter;
 	gboolean 	 valid;
 	char  		 *uri;
 
-	if (sidebar->uri == NULL) {
-		return;
-	}
-
-	/* set selection if any place matches location */
-	selection = gtk_tree_view_get_selection (sidebar->tree_view);
-	gtk_tree_selection_unselect_all (selection);
-	valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (sidebar->store),
-					       &iter);
-
-	while (valid) {
-		gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
-				    PLACES_SIDEBAR_COLUMN_URI, &uri,
-				    -1);
-
-		if (uri != NULL) {
-			if (strcmp (uri, sidebar->uri) == 0) {
-				g_free (uri);
-				gtk_tree_selection_select_iter (selection, &iter);
-				break;
-			}
-			g_free (uri);
-		}
-		valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (sidebar->store),
-						  &iter);
-	}
-}
-
-static void
-loading_uri_callback (NautilusWindow *window,
-		      char *location,
-		      NautilusPlacesSidebar *sidebar)
-{
-        if (g_strcmp0 (sidebar->uri, location) != 0) {
+        if (strcmp (sidebar->uri, location) != 0) {
 		g_free (sidebar->uri);
                 sidebar->uri = g_strdup (location);
+  
+		/* set selection if any place matches location */
+		selection = gtk_tree_view_get_selection (sidebar->tree_view);
+		gtk_tree_selection_unselect_all (selection);
+  		valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (sidebar->store),
+						       &iter);
 
-		update_current_uri (sidebar);
-	}
+		while (valid) {
+			gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter, 
+		 		       	    PLACES_SIDEBAR_COLUMN_URI, &uri,
+					    -1);
+			if (uri != NULL) {
+				if (strcmp (uri, location) == 0) {
+					g_free (uri);
+					gtk_tree_selection_select_iter (selection, &iter);
+					break;
+				}
+				g_free (uri);
+			}
+        	 	valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (sidebar->store),
+							  &iter);
+		}
+    	}
 }
 
 /* Computes the appropriate row and position for dropping */
@@ -1601,7 +1557,7 @@ bookmarks_check_popup_sensitivity (NautilusPlacesSidebar *sidebar)
 	gtk_widget_set_visible (sidebar->popup_menu_add_shortcut_item, (type == PLACES_MOUNTED_VOLUME));
 
 	gtk_widget_set_sensitive (sidebar->popup_menu_remove_item, (type == PLACES_BOOKMARK));
-	gtk_widget_set_sensitive (sidebar->popup_menu_rename_item, (type == PLACES_BOOKMARK));
+	gtk_widget_set_sensitive (sidebar->popup_menu_rename_item, (type == PLACES_BOOKMARK || type == PLACES_XDG_DIR));
 	gtk_widget_set_sensitive (sidebar->popup_menu_empty_trash_item, !nautilus_trash_monitor_is_empty ());
 
  	check_visibility (mount, volume, drive,
@@ -1888,10 +1844,7 @@ add_bookmark (NautilusPlacesSidebar *sidebar)
 
 		location = g_file_new_for_uri (uri);
 		bookmark = nautilus_bookmark_new (location, name);
-
-		if (!nautilus_bookmark_list_contains (sidebar->bookmarks, bookmark)) {
-			nautilus_bookmark_list_append (sidebar->bookmarks, bookmark);
-		}
+		nautilus_bookmark_list_append (sidebar->bookmarks, bookmark);
 
 		g_object_unref (location);
 		g_object_unref (bookmark);
@@ -1923,7 +1876,7 @@ rename_selected_bookmark (NautilusPlacesSidebar *sidebar)
 				    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 				    -1);
 
-		if (type != PLACES_BOOKMARK) {
+		if (type != PLACES_BOOKMARK && type != PLACES_XDG_DIR) {
 			return;
 		}
 
@@ -2844,22 +2797,46 @@ bookmarks_edited (GtkCellRenderer       *cell,
 {
 	GtkTreePath *path;
 	GtkTreeIter iter;
+	gchar *uri;
+	GFile *location;
 	NautilusBookmark *bookmark;
-	int index;
+	PlaceType type;
 
 	g_object_set (cell, "editable", FALSE, NULL);
 	
 	path = gtk_tree_path_new_from_string (path_string);
-	gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->store), &iter, path);
+	if (!gtk_tree_model_get_iter (GTK_TREE_MODEL (sidebar->store), &iter, path)) {
+		goto out;
+	}
+
+	uri = NULL;
 	gtk_tree_model_get (GTK_TREE_MODEL (sidebar->store), &iter,
-		            PLACES_SIDEBAR_COLUMN_INDEX, &index,
+		            PLACES_SIDEBAR_COLUMN_URI, &uri,
+		            PLACES_SIDEBAR_COLUMN_ROW_TYPE, &type,
 		            -1);
-	gtk_tree_path_free (path);
-	bookmark = nautilus_bookmark_list_item_at (sidebar->bookmarks, index);
+	if (!uri) {
+		goto out;
+	}
+
+	location = g_file_new_for_uri (uri);
+	bookmark = nautilus_bookmark_list_item_with_location (sidebar->bookmarks, location, NULL);
 
 	if (bookmark != NULL) {
 		nautilus_bookmark_set_custom_name (bookmark, new_text);
+	} else if (type == PLACES_XDG_DIR) {
+		/* In case we're renaming a built-in bookmark, and it's not in the
+		 * list, add it with a custom name.
+		 */
+		bookmark = nautilus_bookmark_new (location, new_text);
+		nautilus_bookmark_list_append (sidebar->bookmarks, bookmark);
+		g_object_unref (bookmark);
 	}
+
+	g_object_unref (location);
+
+ out:
+	g_free (uri);
+	gtk_tree_path_free (path);
 }
 
 static void
@@ -3082,6 +3059,7 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	GtkTreeViewColumn *col;
 	GtkCellRenderer   *cell;
 	GtkTreeSelection  *selection;
+	GIcon             *eject;
 
 	sidebar->volume_monitor = g_volume_monitor_get ();
 	
@@ -3157,6 +3135,7 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	/* eject icon renderer */
 	cell = gtk_cell_renderer_pixbuf_new ();
 	sidebar->eject_icon_cell_renderer = cell;
+	eject = g_themed_icon_new_with_default_fallbacks ("media-eject-symbolic");
 	g_object_set (cell,
 		      "mode", GTK_CELL_RENDERER_MODE_ACTIVATABLE,
 		      "stock-size", GTK_ICON_SIZE_MENU,
@@ -3165,12 +3144,13 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 			 this even though we tell it not to. */
 		      "xalign", 1.0,
 		      "follow-state", TRUE,
+		      "gicon", eject,
 		      NULL);
 	gtk_tree_view_column_pack_start (col, cell, FALSE);
 	gtk_tree_view_column_set_attributes (col, cell,
 					     "visible", PLACES_SIDEBAR_COLUMN_EJECT,
-					     "gicon", PLACES_SIDEBAR_COLUMN_EJECT_GICON,
 					     NULL);
+	g_object_unref (eject);
 
 	/* normal text renderer */
 	cell = gtk_cell_renderer_text_new ();
@@ -3363,11 +3343,17 @@ nautilus_places_sidebar_set_parent_window (NautilusPlacesSidebar *sidebar,
 	slot = nautilus_window_get_active_slot (window);
 
 	sidebar->bookmarks = nautilus_application_get_bookmarks (app);
+	sidebar->uri = nautilus_window_slot_get_current_uri (slot);
+
 	sidebar->bookmarks_changed_id =
 		g_signal_connect_swapped (sidebar->bookmarks, "changed",
 					  G_CALLBACK (update_places),
 					  sidebar);
 
+	g_signal_connect_object (window, "loading_uri",
+				 G_CALLBACK (loading_uri_callback),
+				 sidebar, 0);
+			 
 	g_signal_connect_object (sidebar->volume_monitor, "volume_added",
 				 G_CALLBACK (volume_added_callback), sidebar, 0);
 	g_signal_connect_object (sidebar->volume_monitor, "volume_removed",
@@ -3388,12 +3374,6 @@ nautilus_places_sidebar_set_parent_window (NautilusPlacesSidebar *sidebar,
 				 G_CALLBACK (drive_changed_callback), sidebar, 0);
 
 	update_places (sidebar);
-
-	g_signal_connect_object (window, "loading-uri",
-				 G_CALLBACK (loading_uri_callback),
-				 sidebar, 0);
-	sidebar->uri = nautilus_window_slot_get_current_uri (slot);
-	update_current_uri (sidebar);
 }
 
 static void
@@ -3481,7 +3461,6 @@ nautilus_shortcuts_model_new (NautilusPlacesSidebar *sidebar)
 		G_TYPE_BOOLEAN,
 		G_TYPE_BOOLEAN,
 		G_TYPE_STRING,
-		G_TYPE_ICON,
 		G_TYPE_INT,
 		G_TYPE_STRING
 	};
