@@ -128,7 +128,6 @@ toolbar_create_toolbutton (NautilusToolbar *self,
 		action = gtk_action_group_get_action (action_group, name);
 		gtk_activatable_set_related_action (GTK_ACTIVATABLE (button), action);
 		gtk_button_set_label (GTK_BUTTON (button), NULL);
-		gtk_widget_set_tooltip_text (button, gtk_action_get_tooltip (action));
 	}
 
 	return button;
@@ -172,8 +171,9 @@ fill_menu (NautilusWindow *window,
 	GList *list;
 
 	slot = nautilus_window_get_active_slot (window);
+	list = back ? nautilus_window_slot_get_back_history (slot) :
+		nautilus_window_slot_get_forward_history (slot);
 
-	list = back ? slot->back_list : slot->forward_list;
 	index = 0;
 	while (list != NULL) {
 		menu_item = nautilus_bookmark_menu_item_new (NAUTILUS_BOOKMARK (list->data));
