@@ -36,7 +36,6 @@
 #include "nautilus-file-management-properties.h"
 #include "nautilus-list-view.h"
 #include "nautilus-notebook.h"
-#include "nautilus-window-manage-views.h"
 #include "nautilus-window-private.h"
 #include "nautilus-desktop-window.h"
 #include "nautilus-properties-window.h"
@@ -310,17 +309,11 @@ action_add_bookmark_callback (GtkAction *action,
 {
 	NautilusWindow *window = user_data;
 	NautilusApplication *app = NAUTILUS_APPLICATION (g_application_get_default ());
-	NautilusBookmark *bookmark;
 	NautilusWindowSlot *slot;
-	NautilusBookmarkList *list;
 
 	slot = nautilus_window_get_active_slot (window);
-	bookmark = slot->current_location_bookmark;
-	list = nautilus_application_get_bookmarks (app);
-
-	if (!nautilus_bookmark_list_contains (list, bookmark)) {
-		nautilus_bookmark_list_append (list, bookmark);
-	}
+	nautilus_bookmark_list_append (nautilus_application_get_bookmarks (app),
+				       nautilus_window_slot_get_bookmark (slot));
 }
 
 static void
@@ -422,19 +415,21 @@ static void
 action_show_hide_search_callback (GtkAction *action,
 				  NautilusWindow *window)
 {
-	NautilusWindowSlot *slot;
 	gboolean active;
 
 	active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	slot = nautilus_window_get_active_slot (window);
-	nautilus_window_slot_set_search_visible (slot, active);
+	nautilus_window_set_search_visible (window, active);
 }
 
 static void
 action_prompt_for_location_callback (GtkAction *action,
 				     NautilusWindow *window)
 {
-	nautilus_window_prompt_for_location (window, "/");
+	GFile *location;
+
+	location = g_file_new_for_path ("/");
+	nautilus_window_prompt_for_location (window, location);
+	g_object_unref (location);
 }
 
 static void
@@ -756,6 +751,7 @@ nautilus_window_finalize_menus (NautilusWindow *window)
 static GList *
 get_extension_menus (NautilusWindow *window)
 {
+	NautilusFile *file;
 	NautilusWindowSlot *slot;
 	GList *providers;
 	GList *items;
@@ -765,6 +761,7 @@ get_extension_menus (NautilusWindow *window)
 	items = NULL;
 
 	slot = nautilus_window_get_active_slot (window);
+	file = nautilus_window_slot_get_file (slot);
 
 	for (l = providers; l != NULL; l = l->next) {
 		NautilusMenuProvider *provider;
@@ -773,7 +770,7 @@ get_extension_menus (NautilusWindow *window)
 		provider = NAUTILUS_MENU_PROVIDER (l->data);
 		file_items = nautilus_menu_provider_get_background_items (provider,
 									  GTK_WIDGET (window),
-									  slot->viewed_file);
+									  file);
 		items = g_list_concat (items, file_items);
 	}
 
