@@ -42,7 +42,6 @@
 #include "nautilus-pathbar.h"
 #include "nautilus-toolbar.h"
 #include "nautilus-view-factory.h"
-#include "nautilus-window-manage-views.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-list-view.h"
 #include "nautilus-canvas-view.h"
@@ -206,10 +205,11 @@ remember_focus_widget (NautilusWindow *window)
 void
 nautilus_window_grab_focus (NautilusWindow *window)
 {
-	if (NAUTILUS_IS_WINDOW (window) &&
-	    window->details->active_slot &&
-	    window->details->active_slot->content_view) {
-		nautilus_view_grab_focus (window->details->active_slot->content_view);
+	NautilusWindowSlot *slot;
+
+	slot = nautilus_window_get_active_slot (window);
+	if (slot) {
+		nautilus_view_grab_focus (nautilus_window_slot_get_view (slot));
 	}
 }
 
@@ -270,6 +270,37 @@ notebook_switch_page_cb (GtkNotebook    *notebook,
 	return FALSE;
 }
 
+void
+nautilus_window_set_search_visible (NautilusWindow *window,
+				    gboolean visible)
+{
+	NautilusWindowSlot *slot;
+
+	slot = window->details->active_slot;
+
+	if (visible) {
+		remember_focus_widget (window);
+		nautilus_window_slot_set_query_editor_visible (slot, TRUE);
+	} else {
+		GFile *location = NULL;
+
+		restore_focus_widget (window);
+
+		/* Use the location bar as the return location */
+		location = nautilus_window_slot_get_query_editor_location (slot);
+
+		/* Last try: use the home directory as the return location */
+		if (location == NULL) {
+			location = g_file_new_for_path (g_get_home_dir ());
+		}
+
+		nautilus_window_go_to (window, location);
+		g_object_unref (location);
+
+		nautilus_window_slot_set_query_editor_visible (slot, FALSE);
+	}
+}
+
 static void
 close_slot (NautilusWindow     *window,
 	    NautilusWindowSlot *slot,
@@ -282,7 +313,6 @@ close_slot (NautilusWindow     *window,
 
 	DEBUG ("Closing slot %p", slot);
 
-	nautilus_window_manage_views_close_slot (slot);
 	window->details->slots = g_list_remove (window->details->slots, slot);
 
 	g_signal_emit (window, signals[SLOT_REMOVED], 0, slot);
@@ -349,10 +379,12 @@ nautilus_window_new_tab (NautilusWindow *window)
 		}
 
 		scheme = g_file_get_uri_scheme (location);
-		if (!strcmp (scheme, "x-nautilus-search")) {
-			g_object_unref (location);
+		if (strcmp (scheme, "x-nautilus-search") == 0) {
 			location = g_file_new_for_path (g_get_home_dir ());
+		} else {
+			g_object_ref (location);
 		}
+
 		g_free (scheme);
 
 		new_slot = nautilus_window_open_slot (window, flags);
@@ -370,7 +402,7 @@ update_cursor (NautilusWindow *window)
 
 	slot = nautilus_window_get_active_slot (window);
 
-	if (slot->allow_stop) {
+	if (nautilus_window_slot_get_allow_stop (slot)) {
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (window)), cursor);
 		g_object_unref (cursor);
@@ -385,7 +417,7 @@ nautilus_window_sync_allow_stop (NautilusWindow *window,
 {
 	GtkAction *stop_action;
 	GtkAction *reload_action;
-	gboolean allow_stop, slot_is_active;
+	gboolean allow_stop, slot_is_active, slot_allow_stop;
 
 	stop_action = gtk_action_group_get_action (nautilus_window_get_main_action_group (window),
 						   NAUTILUS_ACTION_STOP);
@@ -393,13 +425,14 @@ nautilus_window_sync_allow_stop (NautilusWindow *window,
 						     NAUTILUS_ACTION_RELOAD);
 	allow_stop = gtk_action_get_sensitive (stop_action);
 
+	slot_allow_stop = nautilus_window_slot_get_allow_stop (slot);
 	slot_is_active = (slot == nautilus_window_get_active_slot (window));
 
 	if (!slot_is_active ||
-	    allow_stop != slot->allow_stop) {
+	    allow_stop != slot_allow_stop) {
 		if (slot_is_active) {
-			gtk_action_set_visible (stop_action, slot->allow_stop);
-			gtk_action_set_visible (reload_action, !slot->allow_stop);
+			gtk_action_set_visible (stop_action, slot_allow_stop);
+			gtk_action_set_visible (reload_action, !slot_allow_stop);
 		}
 
 		if (gtk_widget_get_realized (GTK_WIDGET (window))) {
@@ -412,18 +445,15 @@ nautilus_window_sync_allow_stop (NautilusWindow *window,
 
 void
 nautilus_window_prompt_for_location (NautilusWindow *window,
-				     const char     *initial)
+				     GFile          *location)
 {
 	GtkWidget *entry;
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+	g_return_if_fail (G_IS_FILE (location));
 
 	entry = nautilus_window_ensure_location_entry (window);
-
-	if (initial) {
-		nautilus_location_entry_set_uri (NAUTILUS_LOCATION_ENTRY (entry),
-						 initial);
-	}
+	nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (entry), location);
 }
 
 /* Code should never force the window taller than this size.
@@ -641,48 +671,50 @@ nautilus_window_slot_close (NautilusWindow     *window,
 	}
 }
 
-void
-nautilus_window_sync_search_widgets (NautilusWindow *window)
+static void
+nautilus_window_sync_bookmarks (NautilusWindow *window)
 {
-	NautilusDirectory *directory;
+	gboolean can_bookmark = FALSE;
 	NautilusWindowSlot *slot;
-	gboolean visible;
+	NautilusBookmarkList *bookmarks;
+	GtkAction *action;
+	GFile *location;
 
 	slot = window->details->active_slot;
-	visible = slot->search_visible;
+	location = nautilus_window_slot_get_location (slot);
 
-	directory = nautilus_directory_get (slot->location);
-	if (NAUTILUS_IS_SEARCH_DIRECTORY (directory)) {
-		visible = TRUE;
+	if (location != NULL) {
+		bookmarks = nautilus_application_get_bookmarks
+			(NAUTILUS_APPLICATION (gtk_window_get_application (GTK_WINDOW (window))));
+		can_bookmark = nautilus_bookmark_list_can_bookmark_location (bookmarks, location);
 	}
 
-	nautilus_window_slot_set_search_visible (slot, visible);
-	nautilus_directory_unref (directory);
+	action = gtk_action_group_get_action (nautilus_window_get_main_action_group (window),
+					      NAUTILUS_ACTION_ADD_BOOKMARK);
+	gtk_action_set_sensitive (action, can_bookmark);
 }
 
 void
 nautilus_window_sync_location_widgets (NautilusWindow *window)
 {
 	NautilusWindowSlot *slot, *active_slot;
+	GFile *location;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 
 	slot = window->details->active_slot;
+	location = nautilus_window_slot_get_location (slot);
 
 	/* Change the location bar and path bar to match the current location. */
-	if (slot->location != NULL) {
-		char *uri;
+	if (location != NULL) {
 		GtkWidget *location_entry;
 		GtkWidget *path_bar;
 
 		location_entry = nautilus_toolbar_get_location_entry (NAUTILUS_TOOLBAR (window->details->toolbar));
-		path_bar = nautilus_toolbar_get_path_bar (NAUTILUS_TOOLBAR (window->details->toolbar));
+		nautilus_location_entry_set_location (NAUTILUS_LOCATION_ENTRY (location_entry), location);
 
-		/* this may be NULL if we just created the slot */
-		uri = nautilus_window_slot_get_location_uri (slot);
-		nautilus_location_entry_set_uri (NAUTILUS_LOCATION_ENTRY (location_entry), uri);
-		g_free (uri);
-		nautilus_path_bar_set_path (NAUTILUS_PATH_BAR (path_bar), slot->location);
+		path_bar = nautilus_toolbar_get_path_bar (NAUTILUS_TOOLBAR (window->details->toolbar));
+		nautilus_path_bar_set_path (NAUTILUS_PATH_BAR (path_bar), location);
 	}
 
 	nautilus_window_sync_up_button (window);
@@ -692,10 +724,12 @@ nautilus_window_sync_location_widgets (NautilusWindow *window)
 	action_group = nautilus_window_get_main_action_group (window);
 
 	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_BACK);
-	gtk_action_set_sensitive (action, active_slot->back_list != NULL);
+	gtk_action_set_sensitive (action, nautilus_window_slot_get_back_history (active_slot) != NULL);
 
 	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_FORWARD);
-	gtk_action_set_sensitive (action, active_slot->forward_list != NULL);
+	gtk_action_set_sensitive (action, nautilus_window_slot_get_forward_history (active_slot) != NULL);
+
+	nautilus_window_sync_bookmarks (window);
 }
 
 GtkWidget *
@@ -723,7 +757,7 @@ path_bar_location_changed_callback (GtkWidget      *widget,
 
 	slot = window->details->active_slot;
 	/* check whether we already visited the target location */
-	i = bookmark_list_get_uri_index (slot->back_list, location);
+	i = bookmark_list_get_uri_index (nautilus_window_slot_get_back_history (slot), location);
 	if (i >= 0) {
 		nautilus_window_back_or_forward (window, TRUE, i, 0);
 	} else {
@@ -759,7 +793,7 @@ path_bar_path_event_callback (NautilusPathBar *path_bar,
 		}
 	} else if (event->button == 3) {
 		slot = nautilus_window_get_active_slot (window);
-		view = slot->content_view;
+		view = nautilus_window_slot_get_view (slot);
 		if (view != NULL) {
 			uri = g_file_get_uri (location);
 			nautilus_view_pop_up_location_context_menu (view, event, uri);
@@ -1122,6 +1156,7 @@ nautilus_window_constructed (GObject *self)
 	NautilusWindow *window;
 	GtkWidget *grid;
 	NautilusWindowSlot *slot;
+	NautilusApplication *application;
 
 	window = NAUTILUS_WINDOW (self);
 
@@ -1169,11 +1204,10 @@ nautilus_window_constructed (GObject *self)
 	slot = nautilus_window_open_slot (window, 0);
 	nautilus_window_set_active_slot (window, slot);
 
-	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
-		nautilus_window_show_sidebar (window);
-	} else {
-		nautilus_window_hide_sidebar (window);
-	}
+	application = NAUTILUS_APPLICATION (g_application_get_default ());
+	window->details->bookmarks_id =
+		g_signal_connect_swapped (nautilus_application_get_bookmarks (application), "changed",
+					  G_CALLBACK (nautilus_window_sync_bookmarks), window);
 
 	nautilus_profile_end (NULL);
 }
@@ -1229,6 +1263,7 @@ static void
 nautilus_window_destroy (GtkWidget *object)
 {
 	NautilusWindow *window;
+	NautilusApplication *application;
 	GList *slots_copy;
 
 	window = NAUTILUS_WINDOW (object);
@@ -1248,6 +1283,13 @@ nautilus_window_destroy (GtkWidget *object)
 
 	window->details->active_slot = NULL;
 
+	if (window->details->bookmarks_id != 0) {
+		application = NAUTILUS_APPLICATION (gtk_window_get_application (GTK_WINDOW (window)));
+		g_signal_handler_disconnect (nautilus_application_get_bookmarks (application),
+					     window->details->bookmarks_id);
+		window->details->bookmarks_id = 0;
+	}
+
 	GTK_WIDGET_CLASS (nautilus_window_parent_class)->destroy (object);
 }
 
@@ -1282,19 +1324,23 @@ nautilus_window_view_visible (NautilusWindow *window,
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	slot = nautilus_window_get_slot_for_view (window, view);
-
-	if (slot->visible) {
+	/* FIXME: this code is odd and should not really be needed, but
+	 * removing it causes bugs, see e.g.
+	 * https://bugzilla.gnome.org/show_bug.cgi?id=679640
+	 *
+	 * Needs more investigation...
+	 */
+	slot = nautilus_view_get_nautilus_window_slot (view);
+	if (g_object_get_data (G_OBJECT (slot), "nautilus-window-view-visible") != NULL) {
 		return;
 	}
 
-	slot->visible = TRUE;
+	g_object_set_data (G_OBJECT (slot), "nautilus-window-view-visible", GINT_TO_POINTER (1));
 
 	/* Look for other non-visible slots */
 	for (l = window->details->slots; l != NULL; l = l->next) {
 		slot = l->data;
-
-		if (!slot->visible) {
+		if (g_object_get_data (G_OBJECT (slot), "nautilus-window-view-visible") == NULL) {
 			return;
 		}
 	}
@@ -1302,7 +1348,6 @@ nautilus_window_view_visible (NautilusWindow *window,
 	/* Look for other non-visible slots */
 	for (l = window->details->slots; l != NULL; l = l->next) {
 		slot = l->data;
-
 		nautilus_window_slot_update_title (slot);
 	}
 
@@ -1344,10 +1389,30 @@ nautilus_window_close (NautilusWindow *window)
 	NAUTILUS_WINDOW_CLASS (G_OBJECT_GET_CLASS (window))->close (window);
 }
 
+/* reports location change to window's "loading-uri" clients, i.e.
+ * sidebar panels [used when switching tabs]. It will emit the pending
+ * location, or the existing location if none is pending.
+ */
+static void
+nautilus_window_report_location_change (NautilusWindow *window)
+{
+	NautilusWindowSlot *slot;
+	gchar *uri;
+
+	slot = nautilus_window_get_active_slot (window);
+	uri = nautilus_window_slot_get_current_uri (slot);
+
+	if (uri != NULL) {
+		g_signal_emit_by_name (window, "loading-uri", uri);
+		g_free (uri);
+	}
+}
+
 void
 nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new_slot)
 {
 	NautilusWindowSlot *old_slot;
+	NautilusView *view;
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 
@@ -1365,9 +1430,10 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 
 	/* make old slot inactive if it exists (may be NULL after init, for example) */
 	if (old_slot != NULL) {
-		/* inform window */
-		if (old_slot->content_view != NULL) {
-			nautilus_window_disconnect_content_view (window, old_slot->content_view);
+		view = nautilus_window_slot_get_view (old_slot);
+		if (view != NULL) {
+			/* inform window */
+			nautilus_window_disconnect_content_view (window, view);
 		}
 
 		/* inform slot & view */
@@ -1378,14 +1444,14 @@ nautilus_window_set_active_slot (NautilusWindow *window, NautilusWindowSlot *new
 
 	/* make new slot active, if it exists */
 	if (new_slot) {
+		view = nautilus_window_slot_get_view (new_slot);
+		if (view != NULL) {
+                        /* inform window */
+                        nautilus_window_connect_content_view (window, view);
+                }
+
 		/* inform sidebar panels */
                 nautilus_window_report_location_change (window);
-		/* TODO decide whether "selection-changed" should be emitted */
-
-		if (new_slot->content_view != NULL) {
-                        /* inform window */
-                        nautilus_window_connect_content_view (window, new_slot->content_view);
-                }
 
 		/* inform slot & view */
                 g_signal_emit_by_name (new_slot, "active");
@@ -1451,7 +1517,7 @@ nautilus_window_key_press_event (GtkWidget *widget,
 	window = NAUTILUS_WINDOW (widget);
 
 	active_slot = nautilus_window_get_active_slot (window);
-	view = active_slot->content_view;
+	view =  nautilus_window_slot_get_view (active_slot);
 
 	if (view != NULL && nautilus_view_get_is_renaming (view)) {
 		/* if we're renaming, just forward the event to the
@@ -1503,60 +1569,12 @@ nautilus_window_key_press_event (GtkWidget *widget,
 	}
 
 	if (nautilus_window_slot_handle_event (window->details->active_slot, event)) {
-		nautilus_window_slot_set_search_visible (window->details->active_slot, TRUE);
 		return TRUE;
 	}
 
 	return FALSE;
 }
 
-/*
- * Main API
- */
-
-static void
-real_sync_view_as_menus (NautilusWindow *window)
-{
-	NautilusWindowSlot *slot;
-	GtkActionGroup *action_group;
-	GtkAction *action;
-
-	g_assert (NAUTILUS_IS_WINDOW (window));
-
-	slot = nautilus_window_get_active_slot (window);
-
-	if (slot->content_view == NULL || slot->new_content_view != NULL) {
-		return;
-	}
-
-	action_group = nautilus_window_get_main_action_group (window);
-
-	if (nautilus_window_slot_content_view_matches_iid (slot, NAUTILUS_LIST_VIEW_ID)) {
-		action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_VIEW_LIST);
-	} else {
-		action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_VIEW_GRID);
-	}
-
-	gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (action), TRUE);
-}
-
-/**
- * nautilus_window_sync_view_as_menus:
- *
- * Set the visible item of the "View as" option menu and
- * the marked "View as" item in the View menu to
- * match the current content view.
- *
- * @window: The NautilusWindow whose "View as" option menu should be synched.
- */
-void
-nautilus_window_sync_view_as_menus (NautilusWindow *window)
-{
-	if (NAUTILUS_WINDOW_CLASS (G_OBJECT_GET_CLASS (window))->sync_view_as_menus != NULL) {
-		NAUTILUS_WINDOW_CLASS (G_OBJECT_GET_CLASS (window))->sync_view_as_menus (window);
-	}
-}
-
 void
 nautilus_window_sync_up_button (NautilusWindow *window)
 {
@@ -1564,13 +1582,14 @@ nautilus_window_sync_up_button (NautilusWindow *window)
 	GtkActionGroup *action_group;
 	NautilusWindowSlot *slot;
 	gboolean allowed;
-	GFile *parent;
+	GFile *parent, *location;
 
 	slot = nautilus_window_get_active_slot (window);
+	location = nautilus_window_slot_get_location (slot);
 
 	allowed = FALSE;
-	if (slot->location != NULL) {
-		parent = g_file_get_parent (slot->location);
+	if (location != NULL) {
+		parent = g_file_get_parent (location);
 		allowed = parent != NULL;
 
 		g_clear_object (&parent);
@@ -1594,7 +1613,7 @@ nautilus_window_sync_title (NautilusWindow *window,
 	}
 
 	if (slot == nautilus_window_get_active_slot (window)) {
-		gtk_window_set_title (GTK_WINDOW (window), slot->title);
+		gtk_window_set_title (GTK_WINDOW (window), nautilus_window_slot_get_title (slot));
 	}
 
 	nautilus_notebook_sync_tab_label (NAUTILUS_NOTEBOOK (window->details->notebook), slot);
@@ -1612,7 +1631,7 @@ nautilus_window_sync_zoom_widgets (NautilusWindow *window)
 	NautilusZoomLevel zoom_level;
 
 	slot = nautilus_window_get_active_slot (window);
-	view = slot->content_view;
+	view = nautilus_window_slot_get_view (slot);
 
 	if (view != NULL) {
 		supports_zooming = nautilus_view_supports_zooming (view);
@@ -1671,12 +1690,11 @@ nautilus_window_connect_content_view (NautilusWindow *window,
 				      NautilusView *view)
 {
 	NautilusWindowSlot *slot;
-	NautilusDirectory *directory;
 
 	g_assert (NAUTILUS_IS_WINDOW (window));
 	g_assert (NAUTILUS_IS_VIEW (view));
 
-	slot = nautilus_window_get_slot_for_view (window, view);
+	slot = nautilus_view_get_nautilus_window_slot (view);
 
 	if (slot != nautilus_window_get_active_slot (window)) {
 		return;
@@ -1688,22 +1706,6 @@ nautilus_window_connect_content_view (NautilusWindow *window,
 
 	/* See the comment in notebook_page_added_cb() */
 	notebook_num_pages_changed (window);
-
-      /* Update displayed view in menu. Only do this if we're not switching
-       * locations though, because if we are switching locations we'll
-       * install a whole new set of views in the menu later (the current
-       * views in the menu are for the old location).
-       */
-	if (slot->pending_location == NULL) {
-		nautilus_window_sync_view_as_menus (window);
-	} else {
-		directory = nautilus_directory_get (slot->pending_location);
-		if (!NAUTILUS_IS_SEARCH_DIRECTORY (directory)) {
-			nautilus_view_grab_focus (view);
-		}
-
-		nautilus_directory_unref (directory);
-	}
 }
 
 void
@@ -1715,7 +1717,7 @@ nautilus_window_disconnect_content_view (NautilusWindow *window,
 	g_assert (NAUTILUS_IS_WINDOW (window));
 	g_assert (NAUTILUS_IS_VIEW (view));
 
-	slot = nautilus_window_get_slot_for_view (window, view);
+	slot = nautilus_view_get_nautilus_window_slot (view);
 
 	if (slot != nautilus_window_get_active_slot (window)) {
 		return;
@@ -1738,6 +1740,12 @@ nautilus_window_show (GtkWidget *widget)
 
 	window = NAUTILUS_WINDOW (widget);
 
+	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
+		nautilus_window_show_sidebar (window);
+	} else {
+		nautilus_window_hide_sidebar (window);
+	}
+
 	GTK_WIDGET_CLASS (nautilus_window_parent_class)->show (widget);	
 
 	gtk_ui_manager_ensure_update (window->details->ui_manager);
@@ -1759,55 +1767,6 @@ nautilus_window_get_main_action_group (NautilusWindow *window)
 	return window->details->main_action_group;
 }
 
-void
-nautilus_window_slot_set_viewed_file (NautilusWindowSlot *slot,
-				      NautilusFile *file)
-{
-	NautilusFileAttributes attributes;
-
-	if (slot->viewed_file == file) {
-		return;
-	}
-
-	nautilus_file_ref (file);
-
-	if (slot->viewed_file != NULL) {
-		nautilus_file_monitor_remove (slot->viewed_file,
-					      slot);
-	}
-
-	if (file != NULL) {
-		attributes =
-			NAUTILUS_FILE_ATTRIBUTE_INFO |
-			NAUTILUS_FILE_ATTRIBUTE_LINK_INFO;
-		nautilus_file_monitor_add (file, slot, attributes);
-	}
-
-	nautilus_file_unref (slot->viewed_file);
-	slot->viewed_file = file;
-}
-
-NautilusWindowSlot *
-nautilus_window_get_slot_for_view (NautilusWindow *window,
-				   NautilusView *view)
-{
-	NautilusWindowSlot *slot;
-	GList *l;
-
-	slot = NULL;
-	for (l = window->details->slots; l; l = l->next) {
-		NautilusWindowSlot *tmp = l->data;
-
-		if (tmp->content_view == view ||
-		    tmp->new_content_view == view) {
-			slot = tmp;
-			break;
-		}
-	}
-
-	return slot;
-}
-
 NautilusWindowSlot *
 nautilus_window_get_active_slot (NautilusWindow *window)
 {
@@ -1930,15 +1889,6 @@ nautilus_window_init (NautilusWindow *window)
 	gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (window), TRUE);
 }
 
-static NautilusIconInfo *
-real_get_icon (NautilusWindow *window,
-               NautilusWindowSlot *slot)
-{
-        return nautilus_file_get_icon (slot->viewed_file, 48,
-				       NAUTILUS_FILE_ICON_FLAGS_IGNORE_VISITING |
-				       NAUTILUS_FILE_ICON_FLAGS_USE_MOUNT_ICON);
-}
-
 static void
 real_window_close (NautilusWindow *window)
 {
@@ -1970,9 +1920,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	wclass->button_press_event = nautilus_window_button_press_event;
 	wclass->delete_event = nautilus_window_delete_event;
 
-	class->get_icon = real_get_icon;
 	class->close = real_window_close;
-	class->sync_view_as_menus = real_sync_view_as_menus;
 
 	properties[PROP_DISABLE_CHROME] =
 		g_param_spec_boolean ("disable-chrome",
